@@ -14,8 +14,8 @@ __title__ = "cobald"
 __summary__ = "COBalD - the Opportunistic Balancing Daemon"
 __url__ = "https://github.com/MatterMiners/cobald"
 
-__version__ = "0.12.1"
+__version__ = "0.12.3"
 __author__ = "Eileen Kuehn, Max Fischer"
-__email__ = "mainekuehn@gmail.com"
-__copyright__ = "2018 - 2020 %s" % __author__
+__email__ = "matterminers@lists.kit.edu"
+__copyright__ = "2018 - 2021 %s" % __author__
 __keywords__ = "opportunistic scheduling scheduler demand feedback-loop cobald"
